#if defined PDCURSES_WINCON
    #include "wincon/pdcclip.c"
    #include "wincon/pdcdisp.c"
    #include "wincon/pdcgetsc.c"
    #include "wincon/pdckbd.c"
    #include "wincon/pdcscrn.c"
    #include "wincon/pdcsetsc.c"
    #include "wincon/pdcutil.c"
#endif